@@ -27,30 +27,33 @@
 
 $pag = "creaprezzi.php";
 
+include("./dati/dati_connessione.php");
+include("./includes/funzioni_$PHPR_DB_TYPE.php");
+connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+include ("./includes/funzioni.php");
+include ("./includes/sett_gio.php");
+$Euro = nome_valuta();
+
 $numcaselle = 8;
 $tableperiodi = periodi . $anno;
 $tablenometariffe = ntariffe . $anno;
 
-include ("dati/connessione_db.php");
-include ("includes/sett_gio.php");
-include ("includes/funzioni.php");
-$Euro = nome_valuta();
-
-$tipo_periodi = pg_exec("select * from anni where idanni = $anno");
-$tipo_periodi = pg_result($tipo_periodi,0,tipo_periodi);
+$tipo_periodi = esegui_query("select * from anni where idanni = $anno");
+$tipo_periodi = risul_query($tipo_periodi,0,tipo_periodi);
 
 # Inserisco la caparra
 if ($modificacaparra) {
-pg_exec("begin");
-pg_exec("lock table $tablenometariffe");
+$tabelle_lock = array("$tablenometariffe");
+$tabelle_lock = lock_tabelle($tabelle_lock);
 $caparra_arrotond = formatta_soldi($caparra_arrotond);
 if (!$caparra_arrotond) { $caparra_arrotond = 1; }
 if (!$caparra_percent) { echo mex("Si deve inserire la percentuale",$pag)."."; }
 else {
-pg_exec("update $tablenometariffe set caparra_percent = $caparra_percent, caparra_arrotond = $caparra_arrotond where idntariffe = 1");
+esegui_query("update $tablenometariffe set $tipotariffa = $caparra_percent where idntariffe = 2");
+esegui_query("update $tablenometariffe set $tipotariffa = $caparra_arrotond where idntariffe = 3");
 echo mex("La caparra  stata modificata",$pag).".";
 } # fine else if (!$caparra_percent)
-pg_exec("commit");
+unlock_tabelle($tabelle_lock);
 echo "
 <form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -62,8 +65,8 @@ else {
 
 # Inserisco i costi aggiuntivi
 if ($inseriscicosti or $modificacosti) {
-pg_exec("begin");
-pg_exec("lock table $tablenometariffe");
+$tabelle_lock = array("$tablenometariffe");
+$tabelle_lock = lock_tabelle($tabelle_lock);
 $inserire = "SI";
 
 if ($costofineaffitto) {
@@ -72,28 +75,27 @@ if (controlla_soldi($costofineaffitto) == "NO") {
 $inserire = "NO";
 echo mex("I soldi del costo finale sono sbagliati",$pag).".<br>";
 } # fine if (controlla_soldi($costofineaffitto) == "NO")
-if ($applicarecfa == "") {
+if ($mostrarecfa == "") {
 $inserire = "NO";
 echo mex("Si deve specificare quando applicare il costo di fine locazione",$pag)." $tipocostosettimanele.<br>";
-} # fine if ($applicarecfa == "")
+} # fine if ($mostrarecfa == "")
 if (!$nomecostofineaffitto) {
 $inserire = "NO";
 echo mex("Si deve inserire il nome del costo aggiuntivo finale",$pag).".<br>";
 } # fine if (!$nomecostofineaffitto)
 else {
-$vecchiocostofineaffitto = pg_exec("select * from $tablenometariffe where tariffa1 = '$nomecostofineaffitto' and costofinale != ''");
-$esistecostofineaffitto = pg_numrows($vecchiocostofineaffitto);
+$vecchiocostofineaffitto = esegui_query("select * from $tablenometariffe where nomecostoagg = '$nomecostofineaffitto' and costofinale != ''");
+$esistecostofineaffitto = numlin_query($vecchiocostofineaffitto);
 if ($esistecostofineaffitto != 0) {
 $inserire = "NO";
 echo mex("Il costo aggiuntivo finale",$pag)." \"$nomecostofineaffitto\" ".mex("gi esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo",$pag).".<br>";
 } # fine if ($esistecostofineaffitto == 0)
 } # fine else if (!$nomecostofineaffitto)
-if ($applicarecfa != "r" and $chiederencf) {
+if ($applicarecf != "n" and $chiederencf) {
 $inserire = "NO";
-echo mex("Per chiedere il numero da moltiplicare, il costo aggiuntivo finale deve essere applicato su richiesta",$pag).".<br>";
-} # fine if ($applicarecfa != "r" and $chiederencf)
-if (!$chiederencf) $chiederencf = "n";
-if (!$letto_agg_cf) $letto_agg_cf = "n";
+echo mex("Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente",$pag).".<br>";
+} # fine if ($applicarecf != "n" and $chiederencf)
+if ($applicarecf == "s") $chiedi_tariffe = "SI";
 } # fine if ($costofineaffitto)
 
 if ($costosettimanale) {
@@ -102,101 +104,215 @@ if (controlla_soldi($costosettimanale) == "NO") {
 $inserire = "NO";
 echo mex("I soldi del costo $parola_settimanale sono sbagliati",$pag).".<br>";
 } # fine if (controlla_soldi($costosettimanale) == "NO")
-if ($applicarecs == "" or $applicarens == "") {
+if ($mostrarecs == "" or $applicarens == "") {
 $inserire = "NO";
 echo mex("Si deve specificare quando applicare il costo $parola_settimanale",$pag)." $tipocostosettimanele ".mex("e il numero di $parola_settimane",$pag).".<br>";
-} # fine if ($applicarecs == "" or $applicarens == "")
-if ($applicarecs != "r") {
+} # fine if ($mostrarecs == "" or $applicarens == "")
+if ($applicarecs != "n") {
 if ($applicarens == "c" or $chiederencs) {
 $inserire = "NO";
-echo mex("Per chiedere il numero di $parola_settimane o il numero da moltiplicare, il costo aggiuntivo $parola_settimanale deve essere applicato su richiesta",$pag).".<br>";
+echo mex("Per chiedere il numero di $parola_settimane o il numero da moltiplicare, il costo aggiuntivo $parola_settimanale non deve essere applicato automaticamente",$pag).".<br>";
 } # fine if ($applicarens == "c" or $chiederencs)
-} # fine if ($applicarecs != "r")
+} # fine if ($applicarecs != "n")
 if (!$nomecostosettimanale) {
 $inserire = "NO";
 echo mex("Si deve inserire il nome del costo aggiuntivo $parola_settimanale",$pag).".<br>";
 } # fine if (!$nomecostosettimanale)
 else {
-$vecchiocostosettimanale = pg_exec("select * from $tablenometariffe where tariffa1 = '$nomecostosettimanale' and costosettimanale != ''");
-$esistecostosettimanale = pg_numrows($vecchiocostosettimanale);
+$vecchiocostosettimanale = esegui_query("select * from $tablenometariffe where nomecostoagg = '$nomecostosettimanale' and costosettimanale != ''");
+$esistecostosettimanale = numlin_query($vecchiocostosettimanale);
 if ($esistecostosettimanale != 0) {
 $inserire = "NO";
 echo mex("Il costo aggiuntivo $parola_settimanale",$pag)." \"$nomecostosettimanale\" ".mex("gi esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo",$pag).".<br>";
 } # fine if ($esistecostosettimanale != 0)
 } # fine else if (!$nomecostosettimanale)
-if (!$chiederencs) { $chiederencs = "n"; }
-if (!$letto_agg_cs) { $letto_agg_cs = "n"; }
+if ($applicarecs == "s") $chiedi_tariffe = "SI";
 } # fine if ($costosettimanale)
 
 if ($costopercentuale) {
-if ($applicarecp == "" or $costop_arrotond == "") {
+if ($mostrarecp == "" or $costop_arrotond == "") {
 $inserire = "NO";
 echo mex("Si deve specificare quando applicare il costo percentuale",$pag)." $tipocostopercentuale ".mex("e il valore dell'arrotondamento",$pag).".<br>";
-} # fine if ($applicarecp == "" or $costop_arrotond == "")
-if ($chiederencp and $applicarecp != "r") {
+} # fine if ($mostrarecp == "" or $costop_arrotond == "")
+if ($chiederencp and $applicarecp != "n") {
 $inserire = "NO";
-echo mex("Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale deve essere applicato su richiesta",$pag).".<br>";
-} # fine if ($applicarens == "c" and $applicarecs != "r")
+echo mex("Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente",$pag).".<br>";
+} # fine if ($applicarens == "c" and $mostrarecs != "r")
 if (!$nomecostopercentuale) {
 $inserire = "NO";
 echo mex("Si deve inserire il nome del costo aggiuntivo percentuale",$pag).".<br>";
 } # fine if (!$nomecostopercentuale)
 else {
-$vecchiocostopercentuale = pg_exec("select * from $tablenometariffe where tariffa1 = '$nomecostopercentuale' and costopercentuale != ''");
-$esistecostopercentuale = pg_numrows($vecchiocostopercentuale);
+$vecchiocostopercentuale = esegui_query("select * from $tablenometariffe where nomecostoagg = '$nomecostopercentuale' and costopercentuale != ''");
+$esistecostopercentuale = numlin_query($vecchiocostopercentuale);
 if ($esistecostopercentuale != 0) {
 $inserire = "NO";
 echo mex("Il costo aggiuntivo percentuale",$pag)." \"$nomecostopercentuale\" ".mex("gi esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo",$pag).".<br>";
 } # fine if ($esistecostopercentuale != 0)
-} # fine else 
-if (!$chiederencp) { $chiederencp = "n"; }
-if (!$letto_agg) { $letto_agg = "n"; }
+} # fine else if (!$nomecostopercentuale)
 $costop_arrotond = formatta_soldi($costop_arrotond);
 if (controlla_soldi($costop_arrotond) == "NO") {
 $inserire = "NO";
 echo mex("I soldi del costo percentuale sono sbagliati",$pag).".<br>";
 } # fine if (controlla_soldi($costop_arrotond) == "NO")
+if ($applicarecp == "s") $chiedi_tariffe = "SI";
 } # fine if ($costopercentuale)
 
 if ($inserire == "SI") {
-$idntariffe = pg_exec("select max(idntariffe) from $tablenometariffe");
-$idntariffe = pg_result($idntariffe,0,max) + 1;
+
+if ($chiedi_tariffe == "SI" and !$tariffe_selezionate) {
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+echo "<form method=\"post\" action=\"creaprezzi.php\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">";
+if ($applicarecf == "s") {
+echo mex("Scegli le tariffe a cui verr applicato automatiamente il costo <b>finale</b>",$pag).":<br>";
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+$tariffa = "tariffa".$numtariffa;
+$nometariffa=risul_query($rigatariffe,0,$tariffa);
+if ($nometariffa == "") {
+$nometariffa = $tariffa;
+$nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
+} # fine if ($nometariffa == "")
+else $nometariffa_vedi = mex("tariffa",$pag)."$numtariffa ($nometariffa)";
+echo "<input type=\"checkbox\" name=\"cf$tariffa\" value=\"s\">$nometariffa_vedi;";
+} # fine for $numtariffa
+echo "<hr width=\"95%\">";
+} # fine if ($applicarecf == "s")
+if ($applicarecs == "s") {
+echo mex("Scegli le tariffe a cui verr applicato automatiamente il costo <b>$parola_settimanale</b>",$pag).":<br>";
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+$tariffa = "tariffa".$numtariffa;
+$nometariffa=risul_query($rigatariffe,0,$tariffa);
+if ($nometariffa == "") {
+$nometariffa = $tariffa;
+$nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
+} # fine if ($nometariffa == "")
+else $nometariffa_vedi = mex("tariffa",$pag)."$numtariffa ($nometariffa)";
+echo "<input type=\"checkbox\" name=\"cs$tariffa\" value=\"s\">$nometariffa_vedi;";
+} # fine for $numtariffa
+echo "<hr width=\"95%\">";
+} # fine if ($applicarecs == "s")
+if ($applicarecp == "s") {
+echo mex("Scegli le tariffe a cui verr applicato automatiamente il costo <b>percentuale</b>",$pag).":<br>";
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+$tariffa = "tariffa".$numtariffa;
+$nometariffa=risul_query($rigatariffe,0,$tariffa);
+if ($nometariffa == "") {
+$nometariffa = $tariffa;
+$nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
+} # fine if ($nometariffa == "")
+else $nometariffa_vedi = mex("tariffa",$pag)."$numtariffa ($nometariffa)";
+echo "<input type=\"checkbox\" name=\"cp$tariffa\" value=\"s\">$nometariffa_vedi;";
+} # fine for $numtariffa
+echo "<hr width=\"95%\">";
+} # fine if ($applicarecp == "s")
+echo "<center>
+<input type=\"hidden\" name=\"inseriscicosti\" value=\"$inseriscicosti\">
+<input type=\"hidden\" name=\"nomecostofineaffitto\" value=\"$nomecostofineaffitto\">
+<input type=\"hidden\" name=\"costofineaffitto\" value=\"$costofineaffitto\">
+<input type=\"hidden\" name=\"mostrarecfa\" value=\"$mostrarecfa\">
+<input type=\"hidden\" name=\"applicarecf\" value=\"$applicarecf\">
+<input type=\"hidden\" name=\"chiederencf\" value=\"$chiederencf\"> 
+<input type=\"hidden\" name=\"letto_agg_cf\" value=\"$letto_agg_cf\">
+<input type=\"hidden\" name=\"nomecostosettimanale\" value=\"$nomecostosettimanale\">
+<input type=\"hidden\" name=\"costosettimanale\" value=\"$costosettimanale\">
+<input type=\"hidden\" name=\"mostrarecs\" value=\"$mostrarecs\">
+<input type=\"hidden\" name=\"applicarecs\" value=\"$applicarecs\">
+<input type=\"hidden\" name=\"applicarens\" value=\"$applicarens\">
+<input type=\"hidden\" name=\"chiederencs\" value=\"$chiederencs\">
+<input type=\"hidden\" name=\"letto_agg_cs\" value=\"$letto_agg_cs\">
+<input type=\"hidden\" name=\"nomecostopercentuale\" value=\"$nomecostopercentuale\">
+<input type=\"hidden\" name=\"costopercentuale\" value=\"$costopercentuale\">
+<input type=\"hidden\" name=\"costop_arrotond\" value=\"$costop_arrotond\">
+<input type=\"hidden\" name=\"mostrarecp\" value=\"$mostrarecp\">
+<input type=\"hidden\" name=\"applicarecp\" value=\"$applicarecp\">
+<input type=\"hidden\" name=\"chiederencp\" value=\"$chiederencp\"> 
+<input type=\"hidden\" name=\"letto_agg\" value=\"$letto_agg\">
+<input type=\"submit\" name=\"tariffe_selezionate\" value=\"".mex("Continua",$pag)."\">
+</center></form><center>
+<form method=\"post\" action=\"creaprezzi.php\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"submit\" name=\"ok\" value=\"".mex("Torna indietro",$pag)."\"><br>
+</form></center>";
+} # fine if ($chiedi_tariffe == "SI" and !$tariffe_selezionate)
+
+else {
+if (!$chiederencf) $chiederencf = "n";
+if (!$letto_agg_cf) $letto_agg_cf = "n";
+if (!$chiederencs) $chiederencs = "n";
+if (!$letto_agg_cs) $letto_agg_cs = "n";
+if (!$chiederencp) $chiederencp = "n";
+if (!$letto_agg) $letto_agg = "n";
+$idntariffe = esegui_query("select max(idntariffe) from $tablenometariffe");
+$idntariffe = risul_query($idntariffe,0,0) + 1;
 if ($costofineaffitto) {
-$regole = $applicarecfa . $chiederencf . $letto_agg_cf;
-pg_exec("insert into $tablenometariffe (idntariffe, costofinale, regole) values ($idntariffe, '$costofineaffitto', '$regole')");
+$regole = $mostrarecfa . $chiederencf . $letto_agg_cf;
+esegui_query("insert into $tablenometariffe (idntariffe, costofinale, regole) values ($idntariffe, '$costofineaffitto', '$regole')");
 if ($nomecostofineaffitto) {
-pg_exec("update $tablenometariffe set tariffa1 = '$nomecostofineaffitto' where idntariffe = $idntariffe");
+esegui_query("update $tablenometariffe set nomecostoagg = '$nomecostofineaffitto' where idntariffe = $idntariffe");
 } # fine if ($nomecostofineaffitto)
+if ($applicarecf == "s" or $applicarecf == "t") {
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+$tariffa = "tariffa".$numtariffa;
+$cftariffa = "cftariffa".$numtariffa;
+if ($$cftariffa or $applicarecf == "t") esegui_query("update $tablenometariffe set $tariffa = '1' where idntariffe = $idntariffe");
+} # fine for $numtariffa
+} # fine if ($applicarecf == "s" or $applicarecf == "t")
 echo mex("Il costo aggiuntivo finale",$pag)." \"$nomecostofineaffitto\" ".mex(" stato inserito",$pag).".<br>";
 $idntariffe++;
 } # fine if ($costofineaffitto)
 if ($costosettimanale) {
-$regole = $applicarecs . $applicarens . $chiederencs . $letto_agg_cs;
-pg_exec("insert into $tablenometariffe (idntariffe, costosettimanale, regole) values ($idntariffe, '$costosettimanale', '$regole')");
+$regole = $mostrarecs . $applicarens . $chiederencs . $letto_agg_cs;
+esegui_query("insert into $tablenometariffe (idntariffe, costosettimanale, regole) values ($idntariffe, '$costosettimanale', '$regole')");
 if ($nomecostosettimanale) {
-pg_exec("update $tablenometariffe set tariffa1 = '$nomecostosettimanale' where idntariffe = $idntariffe");
+esegui_query("update $tablenometariffe set nomecostoagg = '$nomecostosettimanale' where idntariffe = $idntariffe");
 } # fine if ($nomecostosettimanale)
+if ($applicarecs == "s" or $applicarecs == "t") {
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+$tariffa = "tariffa".$numtariffa;
+$cstariffa = "cstariffa".$numtariffa;
+if ($$cstariffa or $applicarecs == "t") esegui_query("update $tablenometariffe set $tariffa = '1' where idntariffe = $idntariffe");
+} # fine for $numtariffa
+} # fine if ($applicarecs == "s" or $applicarecs == "t")
 echo mex("Il costo aggiuntivo $parola_settimanale",$pag)." \"$nomecostosettimanale\" ".mex(" stato inserito",$pag).".<br>";
 $idntariffe++;
 } # fine if ($costosettimanale)
 if ($costopercentuale) {
-$regole = $applicarecp . $chiederencp . $letto_agg;
-pg_exec("insert into $tablenometariffe (idntariffe, costopercentuale, costop_arrotond, regole) values ($idntariffe, '$costopercentuale', '$costop_arrotond', '$regole')");
+$regole = $mostrarecp . $chiederencp . $letto_agg;
+esegui_query("insert into $tablenometariffe (idntariffe, costopercentuale, costop_arrotond, regole) values ($idntariffe, '$costopercentuale', '$costop_arrotond', '$regole')");
 if ($nomecostopercentuale) {
-pg_exec("update $tablenometariffe set tariffa1 = '$nomecostopercentuale' where idntariffe = $idntariffe");
+esegui_query("update $tablenometariffe set nomecostoagg = '$nomecostopercentuale' where idntariffe = $idntariffe");
 } # fine if ($nomecostopercentuale)
+if ($applicarecp == "s" or $applicarecp == "t") {
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+$tariffa = "tariffa".$numtariffa;
+$cptariffa = "cptariffa".$numtariffa;
+if ($$cptariffa or $applicarecp == "t") esegui_query("update $tablenometariffe set $tariffa = '1' where idntariffe = $idntariffe");
+} # fine for $numtariffa
+} # fine if ($applicarecp == "s" or $applicarecp == "t")
 echo mex("Il costo aggiuntivo percentuale",$pag)." \"$nomecostopercentuale\" ".mex(" stato inserito",$pag).".<br>";
 } # fine if ($costopercentuale)
-} # fine if ($inserire == "SI")
-if ($inserire == "NO") {
-echo mex("Nessun dato  stato inserito",$pag).".<br>";
-} # fine if ($inserire == "NO")
-pg_exec("commit");
-echo "
-<form method=\"post\" action=\"creaprezzi.php\">
+echo "<form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"submit\" name=\"ok\" value=\"OK\"><br>
 </form>";
+} # fine else if ($chiedi_tariffe == "SI" and !$tariffe_selezionate)
+} # fine if ($inserire == "SI")
+if ($inserire == "NO") {
+echo mex("Nessun dato  stato inserito",$pag).".<br>";
+echo "<form method=\"post\" action=\"creaprezzi.php\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"submit\" name=\"ok\" value=\"".mex("Torna indietro",$pag)."\"><br>
+</form>";
+} # fine if ($inserire == "NO")
+unlock_tabelle($tabelle_lock);
 } # fine if ($inseriscicosti or $modificacosti)
 
 else {
@@ -206,15 +322,15 @@ if ($inserisci_settimanalmente) {
 $num_tariffa = substr($tipotariffa,7);
 $inizioperiodo = $inizioperiodosett1;
 $fineperiodo = $fineperiodosett1;
-$idinizioperiodo = pg_exec("select idperiodi from $tableperiodi where datainizio = '$inizioperiodo' ");
-$num_idinizioperiodo = pg_numrows($idinizioperiodo);
+$idinizioperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '$inizioperiodo' ");
+$num_idinizioperiodo = numlin_query($idinizioperiodo);
 if ($num_idinizioperiodo == 0) { $idinizioperiodo = 10000; }
-else { $idinizioperiodo = pg_result($idinizioperiodo,0,idperiodi); }
+else { $idinizioperiodo = risul_query($idinizioperiodo,0,idperiodi); }
 $inizioperiodo = $idinizioperiodo;
-$idfineperiodo = pg_exec("select idperiodi from $tableperiodi where datafine = '$fineperiodo' ");
-$num_idfineperiodo = pg_numrows($idfineperiodo);
+$idfineperiodo = esegui_query("select idperiodi from $tableperiodi where datafine = '$fineperiodo' ");
+$num_idfineperiodo = numlin_query($idfineperiodo);
 if ($num_idfineperiodo == 0) { $idfineperiodo = -1; }
-else { $idfineperiodo = pg_result($idfineperiodo,0,idperiodi); }
+else { $idfineperiodo = risul_query($idfineperiodo,0,idperiodi); }
 $fineperiodo = $idfineperiodo ;
 if ($idfineperiodo < $idinizioperiodo) {
 $inserire_prezzi = "NO";
@@ -240,24 +356,24 @@ echo mex("Il formato dei soldi  sbagliato",$pag).". <br>";
 } # fine if ($soldi_sbagliati == "SI")
 
 if ($inserire_prezzi != "NO") {
-pg_exec("begin");
-pg_exec("lock table $tableperiodi");
+$tabelle_lock = array("$tableperiodi");
+$tabelle_lock = lock_tabelle($tabelle_lock);
 for ($num1 = $inizioperiodo ; $num1 < $fineperiodo ; $num1++) {
-if ($prezzoperiodo1domlun) pg_exec("update $tableperiodi set $tipotariffa = $prezzoperiodo1domlun where idperiodi = $num1 ");
+if ($prezzoperiodo1domlun) esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo1domlun where idperiodi = $num1 ");
 $num1++;
-if ($prezzoperiodo1lunmar) pg_exec("update $tableperiodi set $tipotariffa = $prezzoperiodo1lunmar where idperiodi = $num1 ");
+if ($prezzoperiodo1lunmar) esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo1lunmar where idperiodi = $num1 ");
 $num1++;
-if ($prezzoperiodo1marmer) pg_exec("update $tableperiodi set $tipotariffa = $prezzoperiodo1marmer where idperiodi = $num1 ");
+if ($prezzoperiodo1marmer) esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo1marmer where idperiodi = $num1 ");
 $num1++;
-if ($prezzoperiodo1mergio) pg_exec("update $tableperiodi set $tipotariffa = $prezzoperiodo1mergio where idperiodi = $num1 ");
+if ($prezzoperiodo1mergio) esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo1mergio where idperiodi = $num1 ");
 $num1++;
-if ($prezzoperiodo1gioven) pg_exec("update $tableperiodi set $tipotariffa = $prezzoperiodo1gioven where idperiodi = $num1 ");
+if ($prezzoperiodo1gioven) esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo1gioven where idperiodi = $num1 ");
 $num1++;
-if ($prezzoperiodo1vensab) pg_exec("update $tableperiodi set $tipotariffa = $prezzoperiodo1vensab where idperiodi = $num1 ");
+if ($prezzoperiodo1vensab) esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo1vensab where idperiodi = $num1 ");
 $num1++;
-if ($prezzoperiodo1sabdom) pg_exec("update $tableperiodi set $tipotariffa = $prezzoperiodo1sabdom where idperiodi = $num1 ");
+if ($prezzoperiodo1sabdom) esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo1sabdom where idperiodi = $num1 ");
 } # fine for $num1
-pg_exec("commit");
+unlock_tabelle($tabelle_lock);
 echo mex("I prezzi per le settimane dal",$pag)." <b>$inizioperiodosett1</b> ".mex("al",$pag)." <b>$fineperiodosett1</b> ".mex("della <b>tariffa",$pag)."$num_tariffa</b> ".mex("sono stati inseriti",$pag).". <br>";
 } # fine if ($inserire_prezzi != "NO")
 
@@ -275,26 +391,27 @@ else {
 # Inserisco i prezzi (della form da-a)
 
 if ($inserisci or $modifica) {
-pg_exec("begin");
-pg_exec("lock table $tablenometariffe");
-pg_exec("lock table $tableperiodi");
+$tabelle_lock = array("$tablenometariffe","$tableperiodi");
+$tabelle_lock = lock_tabelle($tabelle_lock);
 $inserire = "SI";
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
 
 # Controllo se i campi inseriti sono gi presenti
 $tipotariffa_vedi = mex("tariffa",$pag).substr($tipotariffa,7);
 if ($nometariffa) {
-$vecchionometariffa = pg_exec("select * from $tablenometariffe where idntariffe = 1");
-$esistenometariffa = pg_fieldisnull($vecchionometariffa,0,$tipotariffa) ;
-if ($esistenometariffa == 0) {
+$vecchionometariffa = esegui_query("select * from $tablenometariffe where idntariffe = 1 and $tipotariffa != ''");
+$esistenometariffa = numlin_query($vecchionometariffa) ;
+if ($esistenometariffa > 0) {
 if ($inserisci) {
 echo mex("Il soprannome della",$pag)." $tipotariffa_vedi ".mex("gi esiste, usa il tasto \"modifica i prezzi gi inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi",$pag).".<br>";
 $inserire = "NO";
 } # fine if ($inserisci)
-} # fine if ($esistenometariffa == 0)
-for ($num1 = 1  ; $num1 < 11 ; $num1 = $num1 + 1) {
+} # fine if ($esistenometariffa > 0)
+for ($num1 = 1  ; $num1 <= $numero_tariffe ; $num1 = $num1 + 1) {
 $tariffa_controlla = "tariffa".$num1;
 if ($tariffa_controlla != $tipotariffa) {
-$nome_tariffa_controlla = pg_result($vecchionometariffa,0,$tariffa_controlla);
+$nome_tariffa_controlla = risul_query($rigatariffe,0,$tariffa_controlla);
 if ($nome_tariffa_controlla == $nometariffa) {
 echo mex("Il soprannome",$pag)." $nometariffa ".mex("gi esiste, ne devi usare un'altro",$pag).".<br>";
 $inserire = "NO";
@@ -310,16 +427,16 @@ $inizioperiodo = "inizioperiodo" . $numperiodo;
 $inizioperiodo = $$inizioperiodo;
 $fineperiodo = "fineperiodo" . $numperiodo;
 $fineperiodo = $$fineperiodo;
-$idinizioperiodo = pg_exec("select idperiodi from $tableperiodi where datainizio = '$inizioperiodo' ");
-$num_idinizioperiodo = pg_numrows($idinizioperiodo);
+$idinizioperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '$inizioperiodo' ");
+$num_idinizioperiodo = numlin_query($idinizioperiodo);
 if ($num_idinizioperiodo != 0) {
-$idinizioperiodo = pg_result($idinizioperiodo,0,idperiodi);
+$idinizioperiodo = risul_query($idinizioperiodo,0,idperiodi);
 } # fine if ($num_idinizioperiodo != 0)
 else { $idinizioperiodo = 9999999; }
-$idfineperiodo = pg_exec("select idperiodi from $tableperiodi where datafine = '$fineperiodo' ");
-$num_idfineperiodo = pg_numrows($idfineperiodo);
+$idfineperiodo = esegui_query("select idperiodi from $tableperiodi where datafine = '$fineperiodo' ");
+$num_idfineperiodo = numlin_query($idfineperiodo);
 if ($num_idfineperiodo != 0) {
-$idfineperiodo = pg_result($idfineperiodo,0,idperiodi);
+$idfineperiodo = risul_query($idfineperiodo,0,idperiodi);
 } # fine if ($num_idfineperiodo != 0)
 else { $idfineperiodo = -9999999; }
 $IDinizioperiodo[$numperiodo] = $idinizioperiodo;
@@ -336,12 +453,12 @@ $inserire = "NO";
 } # fine if (inserirepp[$idinizioperiodo] == "SI")
 else {
 $inserirepp[$idinizioperiodo] = "SI";
-$vecchioprezzoperiodo = pg_exec("select $tipotariffa from $tableperiodi where idperiodi = $idinizioperiodo");
-$esisteprezzoperiodo = pg_fieldisnull($vecchioprezzoperiodo,0,$tipotariffa);
-if ($esisteprezzoperiodo == 0 and $inserisci) {
+$vecchioprezzoperiodo = esegui_query("select $tipotariffa from $tableperiodi where idperiodi = $idinizioperiodo and $tipotariffa != ''");
+$esisteprezzoperiodo = numlin_query($vecchioprezzoperiodo);
+if ($esisteprezzoperiodo > 0 and $inserisci) {
 echo mex("Un prezzo nel periodo numero",$pag)." $numperiodo ".mex("esiste gi, usa il tasto \"modifica i prezzi gi inseriti\" per cambiarlo",$pag).". <br>";
 $inserire = "NO";
-} # fine if ($esisteprezzoperiodo == 0 and $inserisci)
+} # fine if ($esisteprezzoperiodo > 0 and $inserisci)
 } # fine else if (inserirepp[$idinizioperiodo] == "SI")
 } # fine for $idinizioperiodo
 if (controlla_soldi($$prezzoperiodo) == "NO") {
@@ -355,7 +472,7 @@ $inserire = "NO";
 # Inserisco i nuovi dati
 if ( $inserire == "SI" ) {
 if ($nometariffa) {
-pg_exec("update $tablenometariffe set $tipotariffa = '$nometariffa' where idntariffe = 1 ");
+esegui_query("update $tablenometariffe set $tipotariffa = '$nometariffa' where idntariffe = 1 ");
 echo mex("Il soprannome della",$pag)." $tipotariffa_vedi ".mex(" stato cambiato",$pag).".<br>";
 } # fine if ($nometariffa)
 for ( $numperiodo = 1; $numperiodo <= $numcaselle; $numperiodo = $numperiodo + 1) {
@@ -366,7 +483,7 @@ $idinizioperiodo = $IDinizioperiodo[$numperiodo];
 $idfineperiodo = $IDfineperiodo[$numperiodo];
 for ( ; $idfineperiodo >= $idinizioperiodo; $idinizioperiodo = $idinizioperiodo
 + 1) {
-pg_exec("update $tableperiodi set $tipotariffa = $prezzoperiodo where idperiodi = $idinizioperiodo ");
+esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo where idperiodi = $idinizioperiodo ");
 } # fine for $idinizioperiodo
 echo mex("Il prezzo del periodo",$pag)." $numperiodo ".mex(" stato inserito",$pag)."!<br>";
 } # fine if ($$prezzoperiodo)
@@ -375,7 +492,7 @@ echo mex("Il prezzo del periodo",$pag)." $numperiodo ".mex(" stato inserito",$pa
 else {
 echo mex("Nessun dato  stato inserito",$pag).".<br>";
 } # fine else if ( $inserire == "SI" )
-pg_exec("commit");
+unlock_tabelle($tabelle_lock);
 echo "
 <form method=\"post\" action=\"creaprezzi.php?anno=$anno\">
 <input type=\"submit\" name=\"ok\" value=\"OK\"><br>
@@ -399,18 +516,22 @@ echo "<br>
 if ($tipo_periodi == "g") echo mex("Inserzione per giorni",$pag)."<br><br>";
 
 echo mex("Prezzi della",$pag)." 
-<select name=\"tipotariffa\">
-<option value=\"tariffa1\" selected>".mex("tariffa",$pag)."1</option>
-<option value=\"tariffa2\">".mex("tariffa",$pag)."2</option>
-<option value=\"tariffa3\">".mex("tariffa",$pag)."3</option>
-<option value=\"tariffa4\">".mex("tariffa",$pag)."4</option>
-<option value=\"tariffa5\">".mex("tariffa",$pag)."5</option>
-<option value=\"tariffa6\">".mex("tariffa",$pag)."6</option>
-<option value=\"tariffa7\">".mex("tariffa",$pag)."7</option>
-<option value=\"tariffa8\">".mex("tariffa",$pag)."8</option>
-<option value=\"tariffa9\">".mex("tariffa",$pag)."9</option>
-<option value=\"tariffa10\">".mex("tariffa",$pag)."10</option>
-</select> ".mex("soprannominata",$pag)."
+<select name=\"tipotariffa\">";
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+$tariffa = "tariffa".$numtariffa;
+$nometariffa=risul_query($rigatariffe,0,$tariffa);
+if ($nometariffa == "") {
+$nometariffa = $tariffa;
+$nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
+} # fine if ($nometariffa == "")
+else $nometariffa_vedi = mex("tariffa",$pag)."$numtariffa ($nometariffa)";
+if ($tariffa == "tariffa1") $selected = " selected";
+else $selected = "";
+echo "<option value=\"$tariffa\"$selected>$nometariffa_vedi</option>";
+} # fine for $numtariffa
+echo "</select> ".mex("soprannominata",$pag)."
 <input type=\"text\" name=\"nometariffa\">
 <br> ";
 
@@ -420,15 +541,15 @@ $fineperiodo = "fineperiodo" . $numperiodo;
 $prezzoperiodo = "prezzoperiodo" . $numperiodo;
 echo "
 $numperiodo. ".mex("Dal",$pag)." <select name=\"$inizioperiodo\">";
-include("dati/selectperiodi$anno.php");
+include("./dati/selectperiodi$anno.php");
 echo "
 </select>
 ".mex("al",$pag)." <select name=\"$fineperiodo\">";
-include("dati/selectperiodi$anno.php");
+include("./dati/selectperiodi$anno.php");
 echo "
 </select>
 :  <input type=\"text\" name=\"$prezzoperiodo\" size=\"15\">$Euro<br>";
-} # fine for
+} # fine for $numperiodo
 
 echo "
 <input type=\"submit\" name=\"inserisci\" value=\"".mex("inserisci i nuovi prezzi",$pag)."\">
@@ -442,15 +563,14 @@ echo mex("Inserzione per settimane",$pag)."<br><br>
 <form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">";
 
-$rigatariffe = pg_exec("select * from $tablenometariffe where idntariffe = 1 ");
-for ($numtariffa = 1 ; $numtariffa < 11 ; $numtariffa++) {
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
 $tariffa = "tariffa".$numtariffa;
-$nometariffa=pg_result($rigatariffe,0,$tariffa);
+$nometariffa=risul_query($rigatariffe,0,$tariffa);
 if ($nometariffa == "") {
 $nometariffa = $tariffa;
 $nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
 } # fine if ($nometariffa == "")
-else $nometariffa_vedi = $nometariffa;
+else $nometariffa_vedi = mex("tariffa",$pag)."$numtariffa ($nometariffa)";
 $tariffa_selected = tariffa_selected . $numtariffa;
 $tariffa_selected = $$tariffa_selected;
 $select_nomi_tariffe .= "
@@ -466,21 +586,21 @@ $file_date = file("dati/selectperiodi$anno.php");
 $num_linee_file_date = count($file_date);
 for ($num1 = 0 ; $num1 < $num_linee_file_date ; $num1++) {
 if (substr($file_date[$num1],0,7) == "<option") {
-$mese_data = substr($file_date[$num1],16,3);
-$giorno_data = substr($file_date[$num1],20,2);
-$anno_data = substr($file_date[$num1],24,4);
-if ($mese_data == "Jan") $mese_data = 1;
-if ($mese_data == "Feb") $mese_data = 2;
-if ($mese_data == "Mar") $mese_data = 3;
-if ($mese_data == "Apr") $mese_data = 4;
-if ($mese_data == "May") $mese_data = 5;
-if ($mese_data == "Jun") $mese_data = 6;
-if ($mese_data == "Jul") $mese_data = 7;
-if ($mese_data == "Aug") $mese_data = 8;
-if ($mese_data == "Sep") $mese_data = 9;
-if ($mese_data == "Oct") $mese_data = 10;
-if ($mese_data == "Nov") $mese_data = 11;
-if ($mese_data == "Dec") $mese_data = 12;
+$mese_data = substr($file_date[$num1],21,2);
+$giorno_data = substr($file_date[$num1],24,2);
+$anno_data = substr($file_date[$num1],16,4);
+#if ($mese_data == "Jan") $mese_data = 1;
+#if ($mese_data == "Feb") $mese_data = 2;
+#if ($mese_data == "Mar") $mese_data = 3;
+#if ($mese_data == "Apr") $mese_data = 4;
+#if ($mese_data == "May") $mese_data = 5;
+#if ($mese_data == "Jun") $mese_data = 6;
+#if ($mese_data == "Jul") $mese_data = 7;
+#if ($mese_data == "Aug") $mese_data = 8;
+#if ($mese_data == "Sep") $mese_data = 9;
+#if ($mese_data == "Oct") $mese_data = 10;
+#if ($mese_data == "Nov") $mese_data = 11;
+#if ($mese_data == "Dec") $mese_data = 12;
 if (date("w", mktime(0,0,0,$mese_data,$giorno_data,$anno_data)) == 0) {
 $file_date[$num1]= str_replace("\\","",$file_date[$num1]);
 $option_domeniche .= $file_date[$num1];
@@ -514,38 +634,50 @@ echo "
 ".mex("Costo aggiuntivo di <b>fine locazione</b> soprannominato",$pag)."
 <input type=\"text\" name=\"nomecostofineaffitto\" size=\"16\"> : 
 <input type=\"text\" name=\"costofineaffitto\" size=\"12\">$Euro<br>
-".mex("da applicare",$pag).":
-<input type=\"radio\" name=\"applicarecfa\" value=\"s\">".mex("sempre",$pag).", 
-<input type=\"radio\" name=\"applicarecfa\" value=\"r\">".mex("su richiesta",$pag).";
-  <input type=\"checkbox\" name=\"chiederencf\" value=\"s\"> 
-".mex("chiedi per quanto deve essere moltiplicato",$pag).";<br>
-<input type=\"checkbox\" name=\"letto_agg_cf\" value=\"s\">
+".mex("mostrare nella pagina di inserzione prenotazioni",$pag).":
+<input type=\"radio\" name=\"mostrarecfa\" value=\"r\" checked>".mex("si",$pag).", 
+<input type=\"radio\" name=\"mostrarecfa\" value=\"s\">".mex("no",$pag).";
+<br>".mex("assegnato automaticamente con tariffe",$pag).":
+<input type=\"radio\" name=\"applicarecf\" value=\"t\">".mex("tutte",$pag).",
+<input type=\"radio\" name=\"applicarecf\" value=\"s\">".mex("scegliere",$pag).",
+<input type=\"radio\" name=\"applicarecf\" value=\"n\" checked>".mex("nessuna",$pag).";
+<br><input type=\"checkbox\" name=\"chiederencf\" value=\"s\"> 
+".mex("chiedi per quanto deve essere moltiplicato",$pag).";
+ <input type=\"checkbox\" name=\"letto_agg_cf\" value=\"s\">
 ".mex("considera il costo finale come letto(i) aggiuntivo(i)",$pag).".<br>
 <hr width=\"25%\">".mex("Costo aggiuntivo <b>$parola_settimanale</b> soprannominato",$pag)."
 <input type=\"text\" name=\"nomecostosettimanale\" size=\"16\"> :
 <input type=\"text\" name=\"costosettimanale\" size=\"12\">$Euro<br>
-".mex("da applicare",$pag).":
-<input type=\"radio\" name=\"applicarecs\" value=\"s\">".mex("sempre",$pag).", 
-<input type=\"radio\" name=\"applicarecs\" value=\"r\">".mex("su richiesta",$pag).";
-".mex("numero di $parola_settimane",$pag).": 
-<input type=\"radio\" name=\"applicarens\" value=\"t\">".mex("tutt$lettera_e",$pag).", 
+".mex("mostrare nella pagina di inserzione prenotazioni",$pag).":
+<input type=\"radio\" name=\"mostrarecs\" value=\"r\" checked>".mex("si",$pag).", 
+<input type=\"radio\" name=\"mostrarecs\" value=\"s\">".mex("no",$pag).";
+<br>".mex("assegnato automaticamente con tariffe",$pag).":
+<input type=\"radio\" name=\"applicarecs\" value=\"t\">".mex("tutte",$pag).",
+<input type=\"radio\" name=\"applicarecs\" value=\"s\">".mex("scegliere",$pag).",
+<input type=\"radio\" name=\"applicarecs\" value=\"n\" checked>".mex("nessuna",$pag).";
+<br>".mex("numero di $parola_settimane",$pag).": 
+<input type=\"radio\" name=\"applicarens\" value=\"t\" checked>".mex("tutt$lettera_e",$pag).", 
 <input type=\"radio\" name=\"applicarens\" value=\"m\">".mex("tutt$lettera_e meno un$lettera_a",$pag).", 
 <input type=\"radio\" name=\"applicarens\" value=\"c\">".mex("chiedere",$pag).";
-  <input type=\"checkbox\" name=\"chiederencs\" value=\"s\"> 
-".mex("chiedi per quanto deve essere moltiplicato",$pag).";<br>
-<input type=\"checkbox\" name=\"letto_agg_cs\" value=\"s\">
+<br><input type=\"checkbox\" name=\"chiederencs\" value=\"s\"> 
+".mex("chiedi per quanto deve essere moltiplicato",$pag).";
+ <input type=\"checkbox\" name=\"letto_agg_cs\" value=\"s\">
 ".mex("considera il costo $parola_settimanale come letto(i) aggiuntivo(i)",$pag).".<br>
 <hr width=\"25%\">".mex("Costo aggiuntivo <b>percentuale</b> soprannominato",$pag)."
 <input type=\"text\" name=\"nomecostopercentuale\" size=\"16\"> :
 <input type=\"text\" name=\"costopercentuale\" size=\"3\" maxlength=\"3\">%
  ".mex("della tariffa arrotondato a",$pag)."
  <input type=\"text\" name=\"costop_arrotond\" size=\"5\">$Euro<br>
-".mex("da applicare",$pag).":
-<input type=\"radio\" name=\"applicarecp\" value=\"s\">".mex("sempre",$pag).", 
-<input type=\"radio\" name=\"applicarecp\" value=\"r\">".mex("su richiesta",$pag).";
- <input type=\"checkbox\" name=\"chiederencp\" value=\"s\"> 
+".mex("mostrare nella pagina di inserzione prenotazioni",$pag).":
+<input type=\"radio\" name=\"mostrarecp\" value=\"r\" checked>".mex("si",$pag).", 
+<input type=\"radio\" name=\"mostrarecp\" value=\"s\">".mex("no",$pag).";
+<br>".mex("assegnato automaticamente con tariffe",$pag).":
+<input type=\"radio\" name=\"applicarecp\" value=\"t\">".mex("tutte",$pag).",
+<input type=\"radio\" name=\"applicarecp\" value=\"s\">".mex("scegliere",$pag).",
+<input type=\"radio\" name=\"applicarecp\" value=\"n\" checked>".mex("nessuna",$pag).";
+<br><input type=\"checkbox\" name=\"chiederencp\" value=\"s\"> 
 ".mex("chiedi per quanto deve essere moltiplicato",$pag)."; 
-<br><input type=\"checkbox\" name=\"letto_agg\" value=\"s\">
+ <input type=\"checkbox\" name=\"letto_agg\" value=\"s\">
 ".mex("considera il costo percentuale come letto(i) aggiuntivo(i)",$pag).".
 <br><center>
 <input type=\"submit\" name=\"inseriscicosti\" value=\"".mex("Inserisci i nuovi costi aggiuntivi",$pag)."\">
@@ -554,8 +686,24 @@ echo "
 
 <form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
-".mex("Caparra",$pag)."</center><br>
-".mex("La caparra normale  del",$pag)." 
+".mex("Caparra",$pag)."</center><br>"
+.mex("La caparra normale per la",$pag)."
+ <select name=\"tipotariffa\">";
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
+$tariffa = "tariffa".$numtariffa;
+$nometariffa=risul_query($rigatariffe,0,$tariffa);
+if ($nometariffa == "") {
+$nometariffa = $tariffa;
+$nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
+} # fine if ($nometariffa == "")
+else $nometariffa_vedi = mex("tariffa",$pag)."$numtariffa ($nometariffa)";
+if ($tariffa == "tariffa1") $selected = " selected";
+else $selected = "";
+echo "<option value=\"$tariffa\"$selected>$nometariffa_vedi</option>";
+} # fine for $numtariffa
+echo "</select> ".mex(" del",$pag)." 
 <input type=\"text\" name=\"caparra_percent\" size=\"2\" maxlength=\"2\">% 
 ".mex("arrotondata a",$pag)."
 <input type=\"text\" name=\"caparra_arrotond\" value=\"10\" size=\"5\">.<br><center>
