@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-@pg_exec("create table $nuova_tableprenota (idprenota integer primary key, idappartamenti text, iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, idprenota_compagna text )");
-pg_exec("delete from $nuova_tableprenota");
+@esegui_query("create table $nuova_tableprenota (idprenota integer primary key, idappartamenti text, iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, idprenota_compagna text )","silenzio");
+esegui_query("delete from $nuova_tableprenota");
 
 ?>
