@@ -27,8 +27,10 @@
 
 $pag = "modifica_app.php";
 
-include ("dati/connessione_db.php");
-include ("includes/funzioni.php");
+include("./dati/dati_connessione.php");
+include("./includes/funzioni_$PHPR_DB_TYPE.php");
+connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+include ("./includes/funzioni.php");
 $tablenometariffe = ntariffe . $anno;
 $tableprenota = prenota .$anno;
 $tableperiodi = periodi . $anno;
@@ -36,43 +38,62 @@ $tableregole = regole . $anno;
 
 
 if ($cancella_app) {
-pg_exec("begin");
-pg_exec("lock table anni");
-$anni_esistenti = pg_exec("select * from anni");
-$num_anni_esistenti = pg_numrows($anni_esistenti);
-for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
-$anno_esistente = pg_result($anni_esistenti,$num1,idanni);
-$tableprenota_lock = prenota . $anno_esistente;
-pg_exec("lock table $tableprenota_lock");
-} # fine for $num1
-pg_exec("lock table appartamenti");
-
-$oggi = date("M d, Y");
+$oggi = date("Y-m-d");
 $anno_attuale = date("Y");
-$anni_da_controllare = pg_exec("select * from anni where idanni >= $anno_attuale");
-$num_anni_da_controllare = pg_numrows($anni_da_controllare);
+
+$anni_esistenti = esegui_query("select * from anni order by idanni");
+$num_anni_esistenti = numlin_query($anni_esistenti);
+$num_tab = 0;
+$num_altre_tab = 0;
+$tabelle_lock[$num_tab] = "anni";
+for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
+$anno_esistente = risul_query($anni_esistenti,$num1,idanni);
+$tableprenota_lock = prenota . $anno_esistente;
+$num_tab++;
+$tabelle_lock[$num_tab] = $tableprenota_lock;
+if ($anno_esistente >= $anno_attuale) {
+$tableperiodi_lock = periodi . $anno_esistente;
+$num_altre_tab++;
+$altre_tab_lock[$num_altre_tab] = $tableperiodi_lock;
+} # fine if ($anno_esistente >= $anno_attuale)
+} # fine for $num1
+$num_tab++;
+$tabelle_lock[$num_tab] = "appartamenti";
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$anni_esistenti2 = esegui_query("select * from anni order by idanni");
+$num_anni_esistenti2 = numlin_query($anni_esistenti2);
+if ($num_anni_esistenti != $num_anni_esistenti2) $cancellare = "NO";
+for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
+$anno_esistente = risul_query($anni_esistenti,$num1,idanni);
+$anno_esistente2 = risul_query($anni_esistenti2,$num1,idanni);
+if ($anno_esistente != $anno_esistente2) $cancellare = "NO";
+} # fine for $num1
+if ($cancellare == "NO") echo mex("<b>L'appartamento non  stato cancellato</b> perch il database  cambiato nel frattempo",$pag).".<br>";
+
+$anni_da_controllare = esegui_query("select * from anni where idanni >= $anno_attuale");
+$num_anni_da_controllare = numlin_query($anni_da_controllare);
 for ($num1 = 0 ;$num1 < $num_anni_da_controllare ; $num1++) {
-$anno_da_controllare = pg_result($anni_da_controllare,$num1,idanni);
+$anno_da_controllare = risul_query($anni_da_controllare,$num1,idanni);
 $tableprenota_da_controllare = prenota . $anno_da_controllare;
 if ($anno_da_controllare == $anno_attuale) {
 $tableperiodi_attuale = periodi . $anno_attuale;
-$idperiodocorrente = pg_exec("select idperiodi from $tableperiodi_attuale where datainizio <= '$oggi' and datafine >= '$oggi' ");
-$numidperiodocorrente = pg_numrows($idperiodocorrente);
+$idperiodocorrente = esegui_query("select idperiodi from $tableperiodi_attuale where datainizio <= '$oggi' and datafine >= '$oggi' ");
+$numidperiodocorrente = numlin_query($idperiodocorrente);
 if ( $numidperiodocorrente >= 1 ) {
 $num_risposta = 0;
 if ($numidperiodocorrente == 2) $num_risposta = 1;
-$idperiodocorrente = pg_result($idperiodocorrente,$num_risposta,idperiodi);
+$idperiodocorrente = risul_query($idperiodocorrente,$num_risposta,idperiodi);
 } # fine if ( $numidperiodocorrente >= 1 )
 else {
-$id_periodi_precedenti = pg_exec("select idperiodi from $tableperiodi_attuale where datainizio <= '$oggi'");
-$num_id_periodi_precedenti = pg_numrows($id_periodi_precedenti);
+$id_periodi_precedenti = esegui_query("select idperiodi from $tableperiodi_attuale where datainizio <= '$oggi'");
+$num_id_periodi_precedenti = numlin_query($id_periodi_precedenti);
 if ($num_id_periodi_precedenti > 0) $idperiodocorrente = 99999;
 else $idperiodocorrente = -1;
 } # fine else if ( $numidperiodocorrente >= 1 )
-$prenota_presenti = pg_exec("select * from $tableprenota_da_controllare where idappartamenti = '$idappartamenti' and iddatainizio >= '$idperiodocorrente'");
+$prenota_presenti = esegui_query("select * from $tableprenota_da_controllare where idappartamenti = '$idappartamenti' and iddatainizio >= '$idperiodocorrente'");
 } # fine if ($anno_da_controllare == $anno_attuale)
-else $prenota_presenti = pg_exec("select * from $tableprenota_da_controllare where idappartamenti = '$idappartamenti'");
-$num_prenota_presenti = pg_numrows($prenota_presenti);
+else $prenota_presenti = esegui_query("select * from $tableprenota_da_controllare where idappartamenti = '$idappartamenti'");
+$num_prenota_presenti = numlin_query($prenota_presenti);
 if ($num_prenota_presenti != 0) {
 $cancellare = "NO";
 echo mex("L'appartamento",$pag)." $idappartamenti ".mex("contiene prenotazione future, non si pu cancellare",$pag).".<br>";
@@ -80,8 +101,8 @@ break;
 } # fine if ($num_prenota_presenti != 0)
 } # fine for $num1
 
-$app_esiste = pg_exec("select * from appartamenti where idappartamenti = '$idappartamenti'");
-$num_app_esiste = pg_numrows($app_esiste);
+$app_esiste = esegui_query("select * from appartamenti where idappartamenti = '$idappartamenti'");
+$num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 1) {
 echo mex("L'appartamento",$pag)." $idappartamenti ".mex(" gi stato cancellato",$pag).".<br>";
 $cancellare = "NO";
@@ -100,14 +121,14 @@ echo mex("Sei sicuro di voler <b>cancellare</b> l'appartamento",$pag)." <b>$idap
 } # fine if ($cancella_sicuro != "SI")
 
 else {
-pg_exec("delete from appartamenti where idappartamenti = '$idappartamenti'");
-$id_appartamenti = pg_exec("select idappartamenti from appartamenti order by idappartamenti ");
-$num_appartamenti = pg_numrows($id_appartamenti);
+esegui_query("delete from appartamenti where idappartamenti = '$idappartamenti'");
+$id_appartamenti = esegui_query("select idappartamenti from appartamenti order by idappartamenti ");
+$num_appartamenti = numlin_query($id_appartamenti);
 $fileaperto = fopen("dati/selectappartamenti.php","w+");
 flock($fileaperto,2);
 fwrite($fileaperto,"<?php \necho \"\n");
 for ( $num = 0; $num < $num_appartamenti; $num = $num + 1) {
-$numapp = pg_result($id_appartamenti,$num,idappartamenti);
+$numapp = risul_query($id_appartamenti,$num,idappartamenti);
 fwrite($fileaperto,"<option value=\\\"$numapp\\\">$numapp</option>
 ");
 } # fine for $num
@@ -132,7 +153,7 @@ echo "
 <br></form>";
 } # fine else if ($cancellare != "NO")
 
-pg_exec("commit");
+unlock_tabelle($tabelle_lock);
 } # fine if ($cancella_app)
 
 else {
@@ -140,27 +161,44 @@ else {
 
 if ($modificaappartamento) {
 
-pg_exec("begin");
+$anni_esistenti = esegui_query("select * from anni order by idanni");
+$num_anni_esistenti = numlin_query($anni_esistenti);
+$num_tab = 0;
+$num_altre_tab = 0;
 if ($n_nome_app and $modificaappartamento == "Continua") {
-pg_exec("lock table anni");
-$anni = pg_exec("select * from anni order by idanni");
-$num_anni = pg_numrows($anni);
-for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
-$anno_lock = pg_result($anni,$num1,idanni);
-$tableprenota_lock = prenota . $anno_lock;
-pg_exec("lock table $tableprenota_lock");
+$tabelle_lock[$num_tab] = "anni";
+for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
+$anno_esistente = risul_query($anni_esistenti,$num1,idanni);
+$tableprenota_lock = prenota . $anno_esistente;
+$num_tab++;
+$tabelle_lock[$num_tab] = $tableprenota_lock;
+} # fine for $num1
+$num_tab++;
+} # fine if ($n_nome_app and $modificaappartamento == "Continua")
+$tabelle_lock[$num_tab] = "appartamenti";
+if ($n_nome_app and $modificaappartamento == "Continua") {
+for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
+$anno_esistente = risul_query($anni_esistenti,$num1,idanni);
+$tableregole_lock = regole . $anno_esistente;
+$num_tab++;
+$tabelle_lock[$num_tab] = $tableregole_lock;
 } # fine for $num1
 } # fine if ($n_nome_app and $modificaappartamento == "Continua")
-pg_exec("lock table appartamenti");
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 if ($n_nome_app and $modificaappartamento == "Continua") {
-for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
-$anno_lock = pg_result($anni,$num1,idanni);
-$tableregole_lock = regole . $anno_lock;
-pg_exec("lock table $tableregole_lock");
+$anni_esistenti2 = esegui_query("select * from anni order by idanni");
+$num_anni_esistenti2 = numlin_query($anni_esistenti2);
+if ($num_anni_esistenti != $num_anni_esistenti2) $modificare = "NO";
+for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
+$anno_esistente = risul_query($anni_esistenti,$num1,idanni);
+$anno_esistente2 = risul_query($anni_esistenti2,$num1,idanni);
+if ($anno_esistente != $anno_esistente2) $modificare = "NO";
 } # fine for $num1
+if ($modificare == "NO") echo mex("<b>L'appartamento non  stato modificato</b> perch il database  cambiato nel frattempo",$pag).".<br>";
 } # fine if ($n_nome_app and $modificaappartamento == "Continua")
-$app_esiste = pg_exec("select * from appartamenti where idappartamenti = '$idappartamenti'");
-$num_app_esiste = pg_numrows($app_esiste);
+
+$app_esiste = esegui_query("select * from appartamenti where idappartamenti = '$idappartamenti'");
+$num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 1) {
 echo mex("L'appartamento",$pag)." $idappartamenti ".mex("non esiste pi",$pag).".<br>";
 $modificare = "NO";
@@ -168,8 +206,8 @@ $tornare_a = "inizio.php";
 } # fine if ($num_app_esiste != 1)
 else $tornare_a = $pag;
 if ($n_nome_app) {
-$app_esiste = pg_exec("select * from appartamenti where idappartamenti = '$n_nome_app'");
-$num_app_esiste = pg_numrows($app_esiste);
+$app_esiste = esegui_query("select * from appartamenti where idappartamenti = '$n_nome_app'");
+$num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 0) {
 echo mex("L'appartamento",$pag)." $n_nome_app ".mex("esiste gi",$pag).".<br>";
 $modificare = "NO";
@@ -182,6 +220,7 @@ if ($modificare != "NO") {
 if ($modificaappartamento != "Continua") {
 $n_commento = stripslashes($n_commento);
 $d_commento = stripslashes($d_commento);
+$n_nome_app = str_replace (",","",$n_nome_app);
 if ($n_nome_app) { echo mex("Il nome dell'appartamento verr cambiato da",$pag)." $idappartamenti ".mex("a",$pag)." $n_nome_app.<br>"; }
 if ($n_numcasa) { echo mex("La casa verr cambiata da",$pag)." $d_numcasa ".mex("a",$pag)." $n_numcasa.<br>"; }
 if ($n_numpiano) { echo mex("Il piano verr cambiato da",$pag)." $d_numpiano ".mex("a",$pag)." $n_numpiano.<br>"; }
@@ -208,15 +247,15 @@ echo "<form method=\"post\" action=\"modifica_app.php\">
 else {
 
 if ($n_nome_app) {
-pg_exec("update appartamenti set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
-for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
-$anno_cambia = pg_result($anni,$num1,idanni);
+esegui_query("update appartamenti set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
+for ($num1 = 0 ; $num1 < $num_anni_esistenti ; $num1++) {
+$anno_cambia = risul_query($anni_esistenti,$num1,idanni);
 $tableprenota_cambia = prenota . $anno_cambia;
-pg_exec("update $tableprenota_cambia set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
-$prenota_c = pg_exec("select * from $tableprenota_cambia where app_assegnabili != '' ");
-$num_prenota_c = pg_numrows($prenota_c);
+esegui_query("update $tableprenota_cambia set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
+$prenota_c = esegui_query("select * from $tableprenota_cambia where app_assegnabili != '' ");
+$num_prenota_c = numlin_query($prenota_c);
 for ($num2 = 0 ; $num2 < $num_prenota_c ; $num2++) {
-$app_assegnabili = pg_result($prenota_c,$num2,app_assegnabili);
+$app_assegnabili = risul_query($prenota_c,$num2,app_assegnabili);
 $app_assegnabili = explode(",",$app_assegnabili);
 $num_app_assegnabili = count($app_assegnabili);
 for ($num3 = 0 ; $num3 < $num_app_assegnabili ; $num3++) {
@@ -226,18 +265,18 @@ $n_app_assegnabili = $app_assegnabili[0];
 for ($num4 = 1 ; $num4 < $num_app_assegnabili ; $num4++) {
 $n_app_assegnabili .= ",".$app_assegnabili[$num4];
 } # fine for $num4
-$idprenota = pg_result($prenota_c,$num2,idprenota);
-pg_exec("update $tableprenota_cambia set app_assegnabili = '$n_app_assegnabili' where idprenota = '$idprenota' ");
+$idprenota = risul_query($prenota_c,$num2,idprenota);
+esegui_query("update $tableprenota_cambia set app_assegnabili = '$n_app_assegnabili' where idprenota = '$idprenota' ");
 break;
 } # fine if ($app_assegnabili[$num3] == $idappartamenti)
 } # fine for $num3
 } # fine for $num2
 $tableregole_cambia = regole . $anno_cambia;
-pg_exec("update $tableregole_cambia set app_agenzia = '$n_nome_app' where app_agenzia = '$idappartamenti' ");
-$regole2 = pg_exec("select * from $tableregole_cambia where tariffa_per_app != '' ");
-$num_regole2 = pg_numrows($regole2);
+esegui_query("update $tableregole_cambia set app_agenzia = '$n_nome_app' where app_agenzia = '$idappartamenti' ");
+$regole2 = esegui_query("select * from $tableregole_cambia where tariffa_per_app != '' ");
+$num_regole2 = numlin_query($regole2);
 for ($num2 = 0 ; $num2 < $num_regole2 ; $num2++) {
-$motivazione = pg_result($regole2,$num2,motivazione);
+$motivazione = risul_query($regole2,$num2,motivazione);
 $motivazione = explode(",",$motivazione);
 $num_motivazione = count($motivazione);
 for ($num3 = 0 ; $num3 < $num_motivazione ; $num3++) {
@@ -247,21 +286,21 @@ $n_motivazione = $motivazione[0];
 for ($num4 = 1 ; $num4 < $num_motivazione ; $num4++) {
 $n_motivazione .= ",".$motivazione[$num4];
 } # fine for $num4
-$idregole = pg_result($regole2,$num2,idregole);
-pg_exec("update $tableregole_cambia set motivazione = '$n_motivazione' where idregole = '$idregole' ");
+$idregole = risul_query($regole2,$num2,idregole);
+esegui_query("update $tableregole_cambia set motivazione = '$n_motivazione' where idregole = '$idregole' ");
 break;
 } # fine if ($motivazione[$num3] == $idappartamenti)
 } # fine for $num3
 } # fine for $num2
 } # fine for $num1
 $idappartamenti = $n_nome_app;
-$id_appartamenti = pg_exec("select idappartamenti from appartamenti order by idappartamenti ");
-$num_appartamenti = pg_numrows($id_appartamenti);
+$id_appartamenti = esegui_query("select idappartamenti from appartamenti order by idappartamenti ");
+$num_appartamenti = numlin_query($id_appartamenti);
 $fileaperto = fopen("dati/selectappartamenti.php","w+");
 flock($fileaperto,2);
 fwrite($fileaperto,"<?php \necho \"\n");
 for ( $num = 0; $num < $num_appartamenti; $num = $num + 1) {
-$numapp = pg_result($id_appartamenti,$num,idappartamenti);
+$numapp = risul_query($id_appartamenti,$num,idappartamenti);
 fwrite($fileaperto,"<option value=\\\"$numapp\\\">$numapp</option>
 ");
 } # fine for $num
@@ -271,25 +310,25 @@ fclose($fileaperto);
 } # fine if ($n_nome_app)
 
 if ($n_numcasa) {
-pg_exec("update appartamenti set numcasa = '$n_numcasa' where idappartamenti = '$idappartamenti' ");
+esegui_query("update appartamenti set numcasa = '$n_numcasa' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_numcasa)
 if ($n_numpiano) {
-pg_exec("update appartamenti set numpiano = '$n_numpiano' where idappartamenti = '$idappartamenti' ");
+esegui_query("update appartamenti set numpiano = '$n_numpiano' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_numpiano)
 if ($n_maxoccupanti) {
-pg_exec("update appartamenti set maxoccupanti = '$n_maxoccupanti' where idappartamenti = '$idappartamenti' ");
+esegui_query("update appartamenti set maxoccupanti = '$n_maxoccupanti' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_maxoccupanti)
 if ($n_priorita) {
-pg_exec("update appartamenti set priorita = '$n_priorita' where idappartamenti = '$idappartamenti' ");
+esegui_query("update appartamenti set priorita = '$n_priorita' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_priorita)
 if ($n_commento != $d_commento) {
-pg_exec("update appartamenti set commento = '$n_commento' where idappartamenti = '$idappartamenti' ");
+esegui_query("update appartamenti set commento = '$n_commento' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_commento != $d_commento)
 echo mex("L'appartamento",$pag)." $idappartamenti ".mex(" stato modificato",$pag).".<br>";
 } # fine else if ($modificaappartamento != "Continua")
 
 } # fine if ($modificare != "NO")
-pg_exec("commit");
+unlock_tabelle($tabelle_lock);
 
 echo "<center>
 <form method=\"post\" action=\"$tornare_a\">
@@ -306,12 +345,12 @@ else {
 # Form per modificare l'appartamento.
 echo "<center><font size=+2><b>".mex("Modifica l'appartamento",$pag)." $idappartamenti.</b></font></center>";
 
-$appartamento = pg_exec("select * from appartamenti where idappartamenti = '$idappartamenti'");
-$d_numcasa = pg_result($appartamento,0,numcasa);
-$d_numpiano = pg_result($appartamento,0,numpiano);
-$d_maxoccupanti = pg_result($appartamento,0,maxoccupanti);
-$d_priorita = pg_result($appartamento,0,priorita);
-$d_commento = pg_result($appartamento,0,commento);
+$appartamento = esegui_query("select * from appartamenti where idappartamenti = '$idappartamenti'");
+$d_numcasa = risul_query($appartamento,0,numcasa);
+$d_numpiano = risul_query($appartamento,0,numpiano);
+$d_maxoccupanti = risul_query($appartamento,0,maxoccupanti);
+$d_priorita = risul_query($appartamento,0,priorita);
+$d_commento = risul_query($appartamento,0,commento);
 
 echo "<br>
 <form method=\"post\" action=\"modifica_app.php\">
