@@ -27,14 +27,17 @@
 
 $pag = "modifica_cliente.php";
 
-include ("dati/connessione_db.php");
-include ("includes/funzioni.php");
-include("dati/lingua.php");
+include("./dati/dati_connessione.php");
+include("./includes/funzioni_$PHPR_DB_TYPE.php");
+connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+include ("./includes/funzioni.php");
+include("./dati/lingua.php");
 $tablenometariffe = ntariffe . $anno;
 $tableprenota = prenota .$anno;
 $tableperiodi = periodi . $anno;
 $tableregole = regole . $anno;
 $stile_soldi = stile_soldi();
+$stile_data = stile_data();
 
 
 
@@ -44,6 +47,7 @@ if ($modifica_cliente != "Continua") {
 if (!$d_cognome) { $d_cognome = "---"; }
 if (!$d_nome) { $d_nome = "---"; }
 if (!$d_datanascita) { $d_datanascita = "---"; }
+else $d_datanascita_f = formatta_data($d_datanascita,$stile_data);
 if (!$d_nazione) { $d_nazione = "---"; }
 if (!$d_citta) { $d_citta= "---"; }
 if (!$d_via) { $d_via = "---"; }
@@ -56,7 +60,8 @@ if (!$d_cap) { $d_cap = "---"; }
 if (!$d_email) { $d_email = "---"; }
 if (!$d_cognome2) { $d_cognome2 = "---"; }
 if (!$d_nome2) { $d_nome2 = "---"; }
-if (!$d_datanascita2) { $d_datanascita2 = "---"; }
+if (!$d_datanascita2) { $d_datanascita2_f = "---"; }
+else $d_datanascita2_f = formatta_data($d_datanascita2,$stile_data);
 
 $n_cognome = stripslashes($n_cognome);
 $n_cognome2 = stripslashes($n_cognome2);
@@ -72,8 +77,9 @@ if ($n_nome) { echo mex("Il nome verr cambiato da",$pag)." <b>$d_nome</b> ".mex(
 if ($n_sesso) { echo mex("Il sesso verr cambiato a",$pag)." <b>$n_sesso</b>.<br>"; }
 if ($n_mesenascita and $n_giornonascita and $n_annonascita) {
 #$n_datanascita = date("M d, Y" , mktime(0,0,0,$n_mesenascita,$n_giornonascita,$n_annonascita));
-$n_datanascita = $n_giornonascita."-".$n_mesenascita."-".$n_annonascita;
-echo mex("La data di nascita  verr cambiata da",$pag)." <b>$d_datanascita</b> ".mex("a",$pag)." <b>$n_datanascita</b>.<br>";
+$n_datanascita = $n_annonascita."-".$n_mesenascita."-".$n_giornonascita;
+$n_datanascita_f = formatta_data($n_datanascita,$stile_data);
+echo mex("La data di nascita  verr cambiata da",$pag)." <b>$d_datanascita_f</b> ".mex("a",$pag)." <b>$n_datanascita_f</b>.<br>";
 } # fine if ($mesenascita and $giornonascita and $annonascita)
 if ($n_telefono) { echo mex("Il telefono verr cambiato da",$pag)." <b>$d_telefono</b> ".mex("a",$pag)." <b>$n_telefono</b>.<br>"; }
 if ($n_nomevia) {
@@ -94,8 +100,9 @@ if ($n_nome2) { echo mex("Il nome n2 verr cambiato da",$pag)." <b>$d_nome2</b> "
 if ($n_sesso2) { echo mex("Il sesso n2 verr cambiato a",$pag)." <b>$n_sesso2</b>.<br>"; }
 if ($n_mesenascita2 and $n_giornonascita2 and $n_annonascita2) {
 #$n_datanascita2 = date("M d, Y" , mktime(0,0,0,$n_mesenascita2,$n_giornonascita2,$n_annonascita2));
-$n_datanascita2 = $n_giornonascita2."-".$n_mesenascita2."-".$n_annonascita2;
-echo mex("La data di nascita n2 verr cambiata da",$pag)." <b>$d_datanascita2</b> ".mex("a",$pag)." <b>$n_datanascita2</b>.<br>";
+$n_datanascita2 = $n_annonascita2."-".$n_mesenascita2."-".$n_giornonascita2;
+$n_datanascita2_f = formatta_data($n_datanascita2,$stile_data);
+echo mex("La data di nascita n2 verr cambiata da",$pag)." <b>$d_datanascita2_f</b> ".mex("a",$pag)." <b>$n_datanascita2_f</b>.<br>";
 } # fine if ($mesenascita2 and $giornonascita2 and $annonascita2)
 if ($n_commento != $d_commento) { echo mex("Il <b>commento</b> verr cambiato",$pag).".<br>"; }
 
@@ -163,113 +170,120 @@ echo "<form method=\"post\" action=\"modifica_cliente.php\">
 } # fine if ($modifica_cliente != "Continua")
 
 else {
-pg_exec("begin");
-pg_exec("lock table clienti");
+$tabelle_lock = array("clienti");
+$tabelle_lock = lock_tabelle($tabelle_lock);
 if ($n_cognome) {
-pg_exec("update clienti set cognome = initcap('$n_cognome') where idclienti = $idclienti ");
+$n_cognome_maius = ucwords($n_cognome);
+esegui_query("update clienti set cognome = '$n_cognome_maius' where idclienti = $idclienti ");
 } # fine if ($n_cognome)
 if ($n_nome) {
-pg_exec("update clienti set nome = initcap('$n_nome') where idclienti = $idclienti ");
+$n_nome_maius = ucwords($n_nome);
+esegui_query("update clienti set nome = '$n_nome_maius' where idclienti = $idclienti ");
 } # fine if ($n_nome)
 if ($n_sesso) {
-pg_exec("update clienti set sesso = '$n_sesso' where idclienti = $idclienti ");
+esegui_query("update clienti set sesso = '$n_sesso' where idclienti = $idclienti ");
 } # fine if ($n_sesso)
 if ($n_datanascita) {
-pg_exec("update clienti set datanascita = '$n_datanascita' where idclienti = $idclienti ");
+esegui_query("update clienti set datanascita = '$n_datanascita' where idclienti = $idclienti ");
 } # fine if ($n_datanascita)
 if ($n_telefono) {
-pg_exec("update clienti set telefono = '$n_telefono' where idclienti = $idclienti ");
+esegui_query("update clienti set telefono = '$n_telefono' where idclienti = $idclienti ");
 } # fine if ($n_telefono)
 if ($n_nomevia) {
-pg_exec("update clienti set via = initcap('$n_nomevia') where idclienti = $idclienti ");
+$n_nomevia_maius = ucwords($n_nomevia);
+esegui_query("update clienti set via = '$n_nomevia_maius' where idclienti = $idclienti ");
 } # fine if ($n_nomevia)
 if ($n_numcivico) {
-pg_exec("update clienti set numcivico = '$n_numcivico' where idclienti = $idclienti ");
+esegui_query("update clienti set numcivico = '$n_numcivico' where idclienti = $idclienti ");
 } # fine if ($n_numcivico)
 if ($n_citta) {
-pg_exec("update clienti set citta = initcap('$n_citta') where idclienti = $idclienti ");
+$n_citta_maius = ucwords($n_citta);
+esegui_query("update clienti set citta = '$n_citta_maius' where idclienti = $idclienti ");
 } # fine if ($n_citta)
 if ($n_nazione) {
-pg_exec("update clienti set nazione = initcap('$n_nazione') where idclienti = $idclienti ");
+$n_nazione_maius = ucwords($n_nazione);
+esegui_query("update clienti set nazione = '$n_nazione_maius' where idclienti = $idclienti ");
 } # fine if ($n_nazione)
 if ($n_cap) {
-pg_exec("update clienti set cap = '$n_cap' where idclienti = $idclienti ");
+esegui_query("update clienti set cap = '$n_cap' where idclienti = $idclienti ");
 } # fine if ($n_cap)
 if ($n_fax) {
-pg_exec("update clienti set fax = '$n_fax' where idclienti = $idclienti ");
+esegui_query("update clienti set fax = '$n_fax' where idclienti = $idclienti ");
 } # fine if ($n_fax)
 if ($n_email) {
-pg_exec("update clienti set email = '$n_email' where idclienti = $idclienti ");
+esegui_query("update clienti set email = '$n_email' where idclienti = $idclienti ");
 } # fine if ($n_email)
 if ($n_telefono2) {
-pg_exec("update clienti set telefono2 = '$n_telefono2' where idclienti = $idclienti ");
+esegui_query("update clienti set telefono2 = '$n_telefono2' where idclienti = $idclienti ");
 } # fine if ($n_telefono2)
 if ($n_telefono3) {
-pg_exec("update clienti set telefono3 = '$n_telefono3' where idclienti = $idclienti ");
+esegui_query("update clienti set telefono3 = '$n_telefono3' where idclienti = $idclienti ");
 } # fine if ($n_telefono3)
 if ($n_cognome2) {
-pg_exec("update clienti set cognome2 = initcap('$n_cognome2') where idclienti = $idclienti ");
+$n_cognome2_maius = ucwords($n_cognome2);
+esegui_query("update clienti set cognome2 = '$n_cognome2_maius' where idclienti = $idclienti ");
 } # fine if ($n_cognome2)
 if ($n_nome2) {
-pg_exec("update clienti set nome2 = initcap('$n_nome2') where idclienti = $idclienti ");
+$n_nome2_maius = ucwords($n_nome2);
+esegui_query("update clienti set nome2 = '$n_nome2_maius' where idclienti = $idclienti ");
 } # fine if ($n_nome2)
 if ($n_sesso2) {
-pg_exec("update clienti set sesso2 = '$n_sesso2' where idclienti = $idclienti ");
+esegui_query("update clienti set sesso2 = '$n_sesso2' where idclienti = $idclienti ");
 } # fine if ($n_sesso2)
 if ($n_datanascita2) {
-pg_exec("update clienti set datanascita2 = '$n_datanascita2' where idclienti = $idclienti ");
+esegui_query("update clienti set datanascita2 = '$n_datanascita2' where idclienti = $idclienti ");
 } # fine if ($n_datanascita2)
 if ($n_commento != $d_commento) {
-pg_exec("update clienti set commento = '$n_commento' where idclienti = $idclienti ");
+esegui_query("update clienti set commento = '$n_commento' where idclienti = $idclienti ");
 } # fine if ($n_commento != $d_commento)
 
 if ($c_nome) {
-pg_exec("update clienti set nome = '' where idclienti = $idclienti ");
+esegui_query("update clienti set nome = '' where idclienti = $idclienti ");
 } # fine if ($c_nome)
 if ($c_datanascita) {
-pg_exec("update clienti set datanascita = null where idclienti = $idclienti ");
+esegui_query("update clienti set datanascita = null where idclienti = $idclienti ");
 } # fine if ($c_datanascita)
 if ($c_telefono) {
-pg_exec("update clienti set telefono = '' where idclienti = $idclienti ");
+esegui_query("update clienti set telefono = '' where idclienti = $idclienti ");
 } # fine if ($c_telefono)
 if ($c_via) {
-pg_exec("update clienti set via = '' where idclienti = $idclienti ");
+esegui_query("update clienti set via = '' where idclienti = $idclienti ");
 } # fine if ($c_via)
 if ($c_numcivico) {
-pg_exec("update clienti set numcivico = '' where idclienti = $idclienti ");
+esegui_query("update clienti set numcivico = '' where idclienti = $idclienti ");
 } # fine if ($c_numcivico)
 if ($c_citta) {
-pg_exec("update clienti set citta = '' where idclienti = $idclienti ");
+esegui_query("update clienti set citta = '' where idclienti = $idclienti ");
 } # fine if ($c_citta)
 if ($c_nazione) {
-pg_exec("update clienti set nazione = '' where idclienti = $idclienti ");
+esegui_query("update clienti set nazione = '' where idclienti = $idclienti ");
 } # fine if ($c_nazione)
 if ($c_cap) {
-pg_exec("update clienti set cap = '' where idclienti = $idclienti ");
+esegui_query("update clienti set cap = '' where idclienti = $idclienti ");
 } # fine if ($c_cap)
 if ($c_fax) {
-pg_exec("update clienti set fax = '' where idclienti = $idclienti ");
+esegui_query("update clienti set fax = '' where idclienti = $idclienti ");
 } # fine if ($c_fax)
 if ($c_email) {
-pg_exec("update clienti set email = '' where idclienti = $idclienti ");
+esegui_query("update clienti set email = '' where idclienti = $idclienti ");
 } # fine if ($c_email)
 if ($c_telefono2) {
-pg_exec("update clienti set telefono2 = '' where idclienti = $idclienti ");
+esegui_query("update clienti set telefono2 = '' where idclienti = $idclienti ");
 } # fine if ($c_telefono2)
 if ($c_telefono3) {
-pg_exec("update clienti set telefono3 = '' where idclienti = $idclienti ");
+esegui_query("update clienti set telefono3 = '' where idclienti = $idclienti ");
 } # fine if ($c_telefono3)
 if ($c_cognome2) {
-pg_exec("update clienti set cognome2 = '' where idclienti = $idclienti ");
+esegui_query("update clienti set cognome2 = '' where idclienti = $idclienti ");
 } # fine if ($c_cognome2)
 if ($c_nome2) {
-pg_exec("update clienti set nome2 = '' where idclienti = $idclienti ");
+esegui_query("update clienti set nome2 = '' where idclienti = $idclienti ");
 } # fine if ($c_nome2)
 if ($c_datanascita2) {
-pg_exec("update clienti set datanascita2 = null where idclienti = $idclienti ");
+esegui_query("update clienti set datanascita2 = null where idclienti = $idclienti ");
 } # fine if ($c_datanascita2)
 echo mex("Il cliente",$pag)." $idclienti ".mex(" stato modificato",$pag).".<br>";
-pg_exec("commit");
+unlock_tabelle($tabelle_lock);
 } # fine else if ($modifica_cliente != "Continua")
 
 echo "<center>
@@ -289,26 +303,28 @@ else {
 # Form per modificare il cliente.
 echo "<center><font size=+2><b>".mex("Modifica i dati del cliente",$pag)." $idclienti</b></font><br></center><br>";
 
-$cliente = pg_exec("select * from clienti where idclienti = $idclienti");
-$d_cognome = pg_result($cliente,0,cognome);
-$d_nome = pg_result($cliente,$num1,nome);
-$d_sesso = pg_result($cliente,$num1,sesso);
-$d_telefono = pg_result($cliente,$num1,telefono);
-$d_via = pg_result($cliente,$num1,via);
-$d_numcivico = pg_result($cliente,$num1,numcivico);
-$d_citta = pg_result($cliente,$num1,citta);
-$d_nazione = pg_result($cliente,$num1,nazione);
-$d_cap = pg_result($cliente,$num1,cap);
-$d_fax = pg_result($cliente,$num1,fax);
-$d_email = pg_result($cliente,$num1,email);
-$d_datanascita = pg_result($cliente,$num1,datanascita);
-$d_telefono2 = pg_result($cliente,$num1,telefono2);
-$d_telefono3 = pg_result($cliente,$num1,telefono3);
-$d_cognome2 = pg_result($cliente,0,cognome2);
-$d_nome2 = pg_result($cliente,$num1,nome2);
-$d_sesso2 = pg_result($cliente,$num1,sesso2);
-$d_datanascita2 = pg_result($cliente,$num1,datanascita2);
-$d_commento = pg_result($cliente,$num1,commento);
+$cliente = esegui_query("select * from clienti where idclienti = $idclienti");
+$d_cognome = risul_query($cliente,0,cognome);
+$d_nome = risul_query($cliente,0,nome);
+$d_sesso = risul_query($cliente,0,sesso);
+$d_telefono = risul_query($cliente,0,telefono);
+$d_via = risul_query($cliente,0,via);
+$d_numcivico = risul_query($cliente,0,numcivico);
+$d_citta = risul_query($cliente,0,citta);
+$d_nazione = risul_query($cliente,0,nazione);
+$d_cap = risul_query($cliente,0,cap);
+$d_fax = risul_query($cliente,0,fax);
+$d_email = risul_query($cliente,0,email);
+$d_datanascita = risul_query($cliente,0,datanascita);
+if ($d_datanascita) $d_datanascita_f = formatta_data($d_datanascita,$stile_data);
+$d_telefono2 = risul_query($cliente,0,telefono2);
+$d_telefono3 = risul_query($cliente,0,telefono3);
+$d_cognome2 = risul_query($cliente,0,cognome2);
+$d_nome2 = risul_query($cliente,0,nome2);
+$d_sesso2 = risul_query($cliente,0,sesso2);
+$d_datanascita2 = risul_query($cliente,0,datanascita2);
+if ($d_datanascita2) $d_datanascita2_f = formatta_data($d_datanascita2,$stile_data);
+$d_commento = risul_query($cliente,0,commento);
 
 echo "<form method=\"post\" action=\"modifica_cliente.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -328,21 +344,23 @@ echo "<form method=\"post\" action=\"modifica_cliente.php\">
 <option value=\"m\">m</option>
 <option value=\"f\">f</option>
 </select></td></tr>
-<tr><td>".mex("Data di nascita",$pag).": <b>$d_datanascita</b></td>
+<tr><td>".mex("Data di nascita",$pag).": <b>$d_datanascita_f</b></td>
 <td>".mex("cambia in",$pag).": 
 <select name=\"n_giornonascita\">
 <option value=\"\" selected>--</option>";
 for ( $num = 1; $num <= 31; $num = $num + 1) {
+if (strlen($num) == 1) $num = "0".$num;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num
 echo "</select>/
 <select name=\"n_mesenascita\">
 <option value=\"\" selected>--</option>";
 for ( $num = 1; $num <= 12; $num = $num + 1) {
+if (strlen($num) == 1) $num = "0".$num;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num
 echo "</select>/
-<input type=\"text\" name=\"n_annonascita\" size=\"4\" maxlength=\"4\" value=\"19\">
+<input type=\"text\" name=\"n_annonascita\" size=\"5\" maxlength=\"4\" value=\"19\">
 <br><input type=\"checkbox\" name=\"c_datanascita\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
 <tr><td>".mex("Telefono",$pag).": <b>$d_telefono</b></td>
 <td>".mex("cambia in",$pag).": 
@@ -406,21 +424,23 @@ echo "</select>/
 <option value=\"m\">m</option>
 <option value=\"f\">f</option>
 </select></td></tr>
-<tr><td>".mex("Data di nascita n2",$pag).": <b>$d_datanascita2</b></td>
+<tr><td>".mex("Data di nascita n2",$pag).": <b>$d_datanascita2_f</b></td>
 <td>".mex("cambia in",$pag).": 
 <select name=\"n_giornonascita2\">
 <option value=\"\" selected>--</option>";
 for ( $num = 1; $num <= 31; $num = $num + 1) {
+if (strlen($num) == 1) $num = "0".$num;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num
 echo "</select>/
 <select name=\"n_mesenascita2\">
 <option value=\"\" selected>--</option>";
 for ( $num = 1; $num <= 12; $num = $num + 1) {
+if (strlen($num) == 1) $num = "0".$num;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num
 echo "</select>/
-<input type=\"text\" name=\"n_annonascita2\" size=\"4\" maxlength=\"4\" value=\"19\">
+<input type=\"text\" name=\"n_annonascita2\" size=\"5\" maxlength=\"4\" value=\"19\">
 <br><input type=\"checkbox\" name=\"c_datanascita2\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
 </table>
 ".mex("Commento",$pag).":<br>
@@ -480,8 +500,8 @@ echo "<center><hr width=\"95%\">
 <input type=\"submit\" name=\"torna\" value=\"".mex("Visualizza il contratto",$pag)."\">
 ".mex("di tipo",$pag)." 
 <select name=\"tipo_contratto\">";
-$nomi_contratti = pg_exec("select valpersonalizza from personalizza where idpersonalizza = 'nomi_contratti'");
-$nomi_contratti = pg_result($nomi_contratti,0,valpersonalizza);
+$nomi_contratti = esegui_query("select valpersonalizza from personalizza where idpersonalizza = 'nomi_contratti'");
+$nomi_contratti = risul_query($nomi_contratti,0,valpersonalizza);
 $nomi_contratti = explode("#@&",$nomi_contratti);
 $num_nomi_contratti = count($nomi_contratti);
 for ($num1 = 0 ; $num1 < $num_nomi_contratti ; $num1++) {
@@ -496,14 +516,14 @@ echo "<option value=\"$num_contratto\">$num_contratto_vedi</option>";
 echo "</select><br></form><hr width=\"95%\">";
 
 
-$anni = pg_exec("select * from anni order by idanni");
-$num_anni = pg_numrows($anni);
+$anni = esegui_query("select * from anni order by idanni");
+$num_anni = numlin_query($anni);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
-$anno_mostra = pg_result($anni,$num1,idanni);
+$anno_mostra = risul_query($anni,$num1,idanni);
 $tableprenota_mostra = prenota. $anno_mostra;
 $tableperiodi_mostra = periodi. $anno_mostra;
-$prenotazioni = pg_exec("select * from $tableprenota_mostra where idclienti = $idclienti");
-$num_prenotazioni = pg_numrows($prenotazioni);
+$prenotazioni = esegui_query("select * from $tableprenota_mostra where idclienti = $idclienti");
+$num_prenotazioni = numlin_query($prenotazioni);
 if ($num_prenotazioni != 0) {
 echo "<br><font size=+1><b>".mex("Prenotazioni del cliente",$pag)." $d_cognome ".mex("nel",$pag)." $anno_mostra</b></font>
 <table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"#b9ccd4\">
@@ -518,34 +538,34 @@ echo "<br><font size=+1><b>".mex("Prenotazioni del cliente",$pag)." $d_cognome "
 <td align=\"center\"><font size=-2>".mex("Pers",$pag).".</font></td>
 <td align=\"center\">".mex("Commento",$pag)."</td></tr>";
 
-$data_inizio_assoluta = pg_exec("select datainizio from $tableperiodi_mostra where idperiodi = 1");
-$data_inizio_assoluta = pg_result($data_inizio_assoluta,0,datainizio);
+$data_inizio_assoluta = esegui_query("select datainizio from $tableperiodi_mostra where idperiodi = 1");
+$data_inizio_assoluta = risul_query($data_inizio_assoluta,0,datainizio);
 $costo_tot_TOT = 0;
 $caparra_TOT = 0;
 $pagato_TOT = 0;
 
 for ($num2 = 0 ; $num2 < $num_prenotazioni ; $num2 = $num2 + 1) {
-$numero = pg_result($prenotazioni,$num2,idprenota);
-$appartamento = pg_result($prenotazioni,$num2,idappartamenti);
-$commento = pg_result($prenotazioni,$num2,commento);
+$numero = risul_query($prenotazioni,$num2,idprenota);
+$appartamento = risul_query($prenotazioni,$num2,idappartamenti);
+$commento = risul_query($prenotazioni,$num2,commento);
 if (!$commento) { $commento = "&nbsp;"; }
 
-$id_data_inizio = pg_result($prenotazioni,$num2,iddatainizio);
+$id_data_inizio = risul_query($prenotazioni,$num2,iddatainizio);
 if ($id_data_inizio == 0) { $data_inizio = "<".$data_inizio_assoluta; }
 else {
-$data_inizio = pg_exec("select * from $tableperiodi_mostra where idperiodi = $id_data_inizio");
-$data_inizio = pg_result($data_inizio,0,datainizio);
+$data_inizio = esegui_query("select * from $tableperiodi_mostra where idperiodi = $id_data_inizio");
+$data_inizio = risul_query($data_inizio,0,datainizio);
 } # fine else if ($id_data_inizio == 0)
-$id_data_fine = pg_result($prenotazioni,$num2,iddatafine);
-$data_fine = pg_exec("select * from $tableperiodi_mostra where idperiodi = $id_data_fine");
-$data_fine = pg_result($data_fine,0,datafine);
+$id_data_fine = risul_query($prenotazioni,$num2,iddatafine);
+$data_fine = esegui_query("select * from $tableperiodi_mostra where idperiodi = $id_data_fine");
+$data_fine = risul_query($data_fine,0,datafine);
 $mese = explode("-",$data_inizio);
 $mese = $mese[1];
 
-$num_persone = pg_result($prenotazioni,$num2,num_persone);
+$num_persone = risul_query($prenotazioni,$num2,num_persone);
 if (!$num_persone or $num_persone == 0) { $num_persone = "?"; }
 $n_letti_agg = 0;
-$costi_aggiuntivi_int = pg_result($prenotazioni,$num2,costiaggiuntivi);
+$costi_aggiuntivi_int = risul_query($prenotazioni,$num2,costiaggiuntivi);
 if ($costi_aggiuntivi_int) {
 $costi_aggiuntivi = explode("#@&",$costi_aggiuntivi_int);
 $num_costi_aggiuntivi = count($costi_aggiuntivi);
@@ -564,13 +584,13 @@ $n_letti_agg = $n_letti_agg + $d_costi_aggiuntivi[2];
 } # fine if ($d_costi_aggiuntivi[0] == "cp" and $d_costi_aggiuntivi[5] == "s")
 } # fine for $numca
 
-$caparra = pg_result($prenotazioni,$num2,caparra);
+$caparra = risul_query($prenotazioni,$num2,caparra);
 if (!$caparra) { $caparra = 0; }
 $caparra_p = punti_in_num($caparra,$stile_soldi);
-$pagato = pg_result($prenotazioni,$num2,pagato);
+$pagato = risul_query($prenotazioni,$num2,pagato);
 if (!$pagato) { $pagato = 0; }
 $pagato_p = punti_in_num($pagato,$stile_soldi);
-$costo_tot = pg_result($prenotazioni,$num2,tariffa_tot);
+$costo_tot = risul_query($prenotazioni,$num2,tariffa_tot);
 if (!$costo_tot) { $costo_tot = 0; }
 $costo_tot_p = punti_in_num($costo_tot,$stile_soldi);
 if ($pagato < $caparra) { $colore = "#CC0000"; }
